# Get gene annotations near LOD peak, given known flowering candidates. First run
# emmax_manhattan_GxE.R, Then update info below "change as needed"

# Near top: change chromosome, experiment, and outfile name

# Thomas Mitchell-Olds, revised 2020-11-27

library(tidyverse)
library(readxl)
library(openxlsx)

# Change as needed for each run:

this.Chr    <- "4"            # A string
expt        <- "B1W2"
peak.nt     <- 13945225       # location of LOD peak for Chr this.Chr
out_name <- str_c(expt, "_Chr", this.Chr, "_", expt, "_Peak.tsv")

# Do not change the following:
half.width  <- 100000           # Center on peak SNP, +/- half.width nt
expt.folder <- str_c("_", expt) # add leading underscore for folder

# Annotations of genes
in_name <- "Bstricta_278_v1.2.annotation_info.xlsx"
infile <- file.path(path.expand("~"),"FlrGWAS","bash", "genome_data", in_name)
df.anot <- read_excel(infile, sheet = 1)
glimpse(df.anot)

# Locations of genes
in_name <- "Bstricta_278_v1.2.gene_exons.chr.gff3.xlsx"
infile <- file.path(path.expand("~"),"FlrGWAS","bash", "genome_data", in_name)
df.locs <- read_excel(infile, sheet = 1)
df.locs <- df.locs %>% mutate(Chr_Num = as.character(Chr_Num))
glimpse(df.locs)

# Get genes near LOD peak
df.local <- df.locs %>% select("Name", "Chr_Num", "Chr_start", "Chr_end") %>% 
               filter(Chr_Num == this.Chr & abs(Chr_start - peak.nt) < half.width)

# Get annotations of each gene
df.anot <- df.anot %>% select("Name", "PFAM", "Panther", "KOG", "KEGG.ec", "KEGG.orthol", 
                              "Gene.ontol", "TAIR.name", "TAIR.symbol", "Best.At.1") #, "Best.At.2", "Best.At.3")
df.merge <- left_join(df.local, df.anot)
df.merge <- unique(df.merge)

df.row <- tibble( Name = "Lod_Peak", Chr_Num = this.Chr, Chr_start= peak.nt, Chr_end= NA, PFAM = NA, 
                  Panther= NA, KOG= NA, KEGG.ec= NA, KEGG.orthol= NA, Gene.ontol= NA, TAIR.name= NA, 
                  TAIR.symbol= NA, Best.At.1= NA) #, Best.At.2= NA,Best.At.3= NA)
df.row <- rbind(df.merge, df.row) %>% arrange(Chr_start) # Sort LOD peak into middle

# Output local results
outfile  <- file.path(path.expand("~"),"FlrGWAS","bash", expt.folder, out_name)
# write(outfile)
write_tsv(df.row, outfile)
print(df.row, n = 50)
