# Tom Mitchell-Olds, 2020-06-25
# Produces QQ-plot for P-values from emmax GWAS

library(tidyverse)

expt <- "B5" # Experiment, and file location. Change as needed for each run

expt.folder <- str_c("_", expt) # add leading underscore for folder

# Get genome-wide file from emmax
# in_name <- str_c("Ref", expt.folder, ".txt_emmax.ps.mod")
in_name <- str_c(expt, ".txt_emmax.ps.mod")
infile  <- file.path(path.expand("~"),"FlrGWAS","bash", expt.folder, in_name)
df      <- read_tsv(infile)
names(df) <- c("ChrNt", "EffectSize", "Pval", "Chr", "SNPpos")
df <- df %>% mutate(ChrNt = as.character(ChrNt),
                    Chr   = as.character(Chr))
dim(df)
head(df)


# QQ plot - test whether P-values are uniformly distributed from 0 to 1
# Location to output graph
graph_pathQQ <- file.path(path.expand("~"),"FlrGWAS","bash", 
                          expt.folder, str_c(expt, "_QQ.png"))
df2 <- df %>% arrange(Pval) # Check data for all chromosomes together
y <- as.vector(df2$Pval)
probs <- (1:length(y))/(length(y) + 1)
uniform.quantiles = qunif(probs, min = 0, max = 1)
df.qq <- tibble(vertical = y, uq = uniform.quantiles) 
png(file=graph_pathQQ, width=600, height=600)
ggplot(df.qq, aes(x = uq, y = vertical)) + geom_point() + 
  geom_abline(slope = 1, intercept = 0, color='red') +
  labs(x = "Uniform Quantiles", y = "P-values", 
       title = str_c("QQ-plot for Experiment ", expt)) +
  theme_classic()
dev.off()

cat("QQplot completed for experiment ", expt, "\n")

cat("Data input from file", in_name, "\n")

cat("Number of SNPs:", length(y))

