# From emmax output file, find most significant SNP on chosen chromosome. First
# run this program. Then update "info "change as needed in annotations.R


library(tidyverse)

# Change as needed for each run

Chr_Num <- "4"  # A string
expt    <- "E1"

# Do not change these next items
half.width <- 100000            # Center on peak SNP, +/- half.width nt
expt.folder <- str_c("_", expt) # add leading underscore for folder
Sig.thresh <- 8.0 # A constant, do not change

# Get genome-wide file from emmax
in_name <- str_c(expt, ".BLUPs_ID.txt_emmax.ps.mod")
infile  <- file.path(path.expand("~"),"FlrGWAS","bash", expt.folder, in_name)
df      <- read_tsv(infile)
names(df) <- c("ChrNt", "EffectSize", "Pval", "Chr", "SNPpos")
df <- df %>% mutate(ChrNt = as.character(ChrNt),
                    Chr   = as.character(Chr))

# QQ plot
graph_pathQQ <- file.path(path.expand("~"),"FlrGWAS","bash", expt.folder, str_c(expt, "_QQ.png"))
# df2 <- df %>% filter(Chr == Chr_Num) %>% arrange(Pval) # Just this chromosome
df2 <- df %>% arrange(Pval)                              # All chromosomes
y <- as.vector(df2$Pval)
probs <- (1:length(y))/(length(y) + 1)
uniform.quantiles = qunif(probs, min = 0, max = 1)
df.qq <- tibble(vertical = y, uq = uniform.quantiles) 
png(file=graph_pathQQ, width=600, height=600)
ggplot(df.qq, aes(x = uq, y = vertical)) + geom_point() + 
  geom_abline(slope = 1, intercept = 0, color='red') +
  labs(x = "Uniform Quantiles", y = "P-values", 
       title = str_c("QQ-plot for Experiment ", expt)) +
  theme_classic()
dev.off()

# Focus on particular chromosome
df.chr <- df %>% filter(Chr == Chr_Num) %>% 
                 mutate(kb   = SNPpos / 1000,
                        logP = -1 * log10(Pval)) 
                 # %>% filter(SNPpos < 24300000) # used to mask another peak
  
wm <- which.max(df.chr$logP)
(max.SNP <- df.chr[[wm ,5]])
left.margin  <- max.SNP - half.width
right.margin <- max.SNP + half.width
max.kb <- max.SNP / 1000
graph_name1 <- str_c(expt, "_Chr", Chr_Num, "_all.png")
graph_path1  <- file.path(path.expand("~"),"FlrGWAS","bash", expt.folder, graph_name1)
png(file=graph_path1, width=600, height=500)
ggplot(df.chr, aes(x = kb, y = logP)) + geom_point()  +
   geom_vline(xintercept = max.kb, color = "red") +
   geom_hline(yintercept = Sig.thresh, color = "blue") + 
   labs(x = "Kilobases", y = "Log10P",
        title = str_c("Manhattan plot for chromosome ", Chr_Num)) +
   theme_classic()
dev.off()

# Near LOD peak
graph_name2 <- str_c(expt, "_Chr", Chr_Num, "_near.png")
graph_path2  <- file.path(path.expand("~"),"FlrGWAS","bash", expt.folder, graph_name2)
png(file=graph_path2, width=600, height=500)
df.near <- df.chr %>% filter(SNPpos >= left.margin & SNPpos <= right.margin)
ggplot(df.near, aes(x = kb, y = logP)) + geom_point() +
   geom_vline(xintercept = max.kb, color = "red") +
   geom_hline(yintercept = Sig.thresh, color = "blue") + 
   labs(x = "Kilobases", y = "Log10P",
        title = str_c("Manhattan plot closeup for chromosome ", Chr_Num)) +
   theme_classic()
dev.off()

str_c("Experiment ", expt, ", most significant SNP in chromosome ", Chr_Num, ":")
max.SNP

max(df.chr$logP)
